ListNode class

Inheritance

Constructors

ListNode(bool ordered, [List<MarkdownNode> children = const []])

Properties

children List<MarkdownNode>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
ordered bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited