MarkdownStyle class

Annotations

Constructors

MarkdownStyle({TextStyle baseStyle = const TextStyle(), TextStyle? h1Style, TextStyle? h2Style, TextStyle? h3Style, TextStyle? paragraphStyle, TextStyle? boldStyle, TextStyle? italicStyle, TextStyle? codeStyle, TextStyle? listItemStyle, EdgeInsets? paragraphPadding, EdgeInsets? headerPadding, TextOverflow textOverflow = TextOverflow.clip, int? maxLines, bool softWrap = true, MainAxisSize mainAxisSize = MainAxisSize.max, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start})
const

Properties

baseStyle TextStyle
final
bold TextStyle
final
code TextStyle
final
crossAxisAlignment CrossAxisAlignment
final
h1 TextStyle
final
h2 TextStyle
final
h3 TextStyle
final
hashCode int
The hash code for this object.
no setterinherited
headerPadding EdgeInsets?
final
italic TextStyle
final
listItem TextStyle
final
mainAxisSize MainAxisSize
final
maxLines int?
final
paragraph TextStyle
final
paragraphPadding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool
final
textOverflow TextOverflow
final

Methods

copyWith({TextStyle? baseStyle, TextStyle? h1Style, TextStyle? h2Style, TextStyle? h3Style, TextStyle? boldStyle, TextStyle? italicStyle, TextStyle? codeStyle, TextStyle? listItemStyle, TextStyle? paragraphStyle, EdgeInsets? paragraphPadding, EdgeInsets? headerPadding, TextOverflow? textOverflow, int? maxLines, bool? softWrap, MainAxisSize? mainAxisSize, CrossAxisAlignment? crossAxisAlignment}) MarkdownStyle
getHeaderStyle(int level) TextStyle
getTextStyle(MarkdownNode node) TextStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited